@@ -15,6 +15,7 @@ __all__ = [
     "get_corpus",
     "get_corpus_db",
     "get_corpus_db_detail",
+    "get_corpus_default_db",
     "get_corpus_path",
     "provinces",
     "remove",
@@ -25,12 +26,13 @@ __all__ = [
     "thai_stopwords",
     "thai_syllables",
     "thai_words",
+    "path_pythainlp_corpus",
 ]
 
 import os
-from tinydb import TinyDB
 
 from pythainlp.tools import get_full_data_path, get_pythainlp_path
+from tinydb import TinyDB
 
 # Remote and local corpus databases
 
@@ -39,9 +41,7 @@ _CORPUS_PATH = os.path.join(get_pythainlp_path(), _CORPUS_DIRNAME)
 
 # remote corpus catalog URL
 _CORPUS_DB_URL = (
-    "https://raw.githubusercontent.com/"
-    "PyThaiNLP/pythainlp-corpus/"
-    "2.2/db.json"
+    "https://pythainlp.github.io/pythainlp-corpus/db.json"
 )
 
 # local corpus catalog filename
@@ -52,7 +52,7 @@ _CORPUS_DB_PATH = get_full_data_path(_CORPUS_DB_FILENAME)
 
 # create a local corpus database if it does not already exist
 if not os.path.exists(_CORPUS_DB_PATH):
-    TinyDB(_CORPUS_DB_PATH)
+    TinyDB(_CORPUS_DB_PATH).close()
 
 
 def corpus_path() -> str:
@@ -81,8 +81,10 @@ from pythainlp.corpus.core import (
     get_corpus,
     get_corpus_db,
     get_corpus_db_detail,
+    get_corpus_default_db,
     get_corpus_path,
     remove,
+    path_pythainlp_corpus,
 )  # these imports must come before other pythainlp.corpus.* imports
 from pythainlp.corpus.common import (
     countries,
